@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '1.06';
+$VERSION = '1.07';
 
 #----------------------------------------------------------------------------
 
@@ -167,7 +167,7 @@ documentation, please submit a bug to the RT system (see link below). However,
 it would help greatly if you are able to pinpoint problems or even supply a
 patch.
 
-Fixes are dependant upon their severity and my availablity. Should a fix not
+Fixes are dependent upon their severity and my availability. Should a fix not
 be forthcoming, please feel free to (politely) remind me by sending an email
 to barbie@cpan.org .
 
@@ -182,14 +182,6 @@ here steals from Tony's module.
 
 See L<Games::Boggle> if you want a traditional Boggle rules module.
 
-=head1 DSLIP
-
-  R - Released
-  d - Developer
-  p - Perl only
-  O - Object oriented
-  p - Standard Perl
-
 =head1 AUTHOR
 
   Barbie, <barbie@cpan.org>
@@ -197,14 +189,10 @@ See L<Games::Boggle> if you want a traditional Boggle rules module.
 
 =head1 COPYRIGHT
 
-    Copyright  2003-2007 Barbie for Miss Barbell Productions.
+  Copyright (C) 2003-2012 Barbie for Miss Barbell Productions.
 
-    This library is free software; you can redistribute it and/or modify it under
-    the same terms as Perl itself, using the Artistic License.
-
-The full text of the licenses can be found in the Artistic file included with
-this distribution, or in perlartistic file as part of Perl installation, in
-the 5.8.1 release or later.
+  This module is free software; you can redistribute it and/or
+  modify it under the Artistic License 2.0.
 
 =cut
 
